#version 330

uniform sampler2D blurredExp;
uniform sampler2D texUnit;
uniform vec4 diffuse;
uniform vec4 lightDirection;
uniform int texCount;
uniform float k = 200;


in vec2 texCoordV;
in vec4 projShadowCoord;
in vec3 normalV, lightDir;
in vec4 pos;

out vec4 outColor;

void main()
{
	float shadowTerm=0;
	vec4 color, diff;

	if (texCount  != 2)
		diff = texture(texUnit, texCoordV) ;
	else 
		diff = diffuse;
		
	// ambient term = shadowed	
	color = diff * 0.25;
	
	vec3 n = normalize (normalV);
	
	float NdotL = max(0.0,dot (n, lightDir));
	
	float distToLight = dot(vec3(lightDirection), vec3(pos) + 250*vec3(lightDirection))/800.0;

	float expz;
	if (NdotL > 0.0) {
		vec4 proj = projShadowCoord / projShadowCoord.w; 
		expz = texture(blurredExp, proj.xy).x;
		shadowTerm = exp(-k*distToLight) * expz;
		shadowTerm = clamp(shadowTerm, 0 , 1);
		color += diff  * NdotL * shadowTerm ;
	}
	
	outColor = color;
}
