#version 330

uniform sampler2D blurredMoments;
uniform sampler2D texUnit;
uniform vec4 diffuse;
uniform vec4 lightDirection;
uniform int texCount;


in vec2 texCoordV;
in vec4 projShadowCoord;
in vec3 normalV, lightDir;
in vec4 pos;

out vec4 outColor;

void main()
{
	float shadowTerm=0;
	vec4 color, diff;

	if (texCount  != 2)
		diff = texture(texUnit, texCoordV) ;
	else 
		diff = diffuse;
		
	// ambient term = shadowed	
	color = diff * 0.25;
	
	vec3 n = normalize (normalV);
	
	float NdotL = max(0.0,dot (n, lightDir));
	
	float distToLight = dot(vec3(lightDirection), vec3(pos) + 250*vec3(lightDirection))/400.0;

	vec2 moments;
	float p=0;
	if (NdotL > 0.0) {
		vec4 proj = projShadowCoord / projShadowCoord.w; 
		moments = texture(blurredMoments, proj.xy).xy;
		if (distToLight <= moments.x) 
			shadowTerm = 1.0;
		else {
			float var = max(0.00002, moments.y - (moments.x * moments.x));
			float diff = distToLight - moments.x;
			shadowTerm = var / (var + diff*diff);
		}
		color += diff  * NdotL * shadowTerm ;
	}
	if (distToLight < 0)
		outColor = vec4(1,0,0,0);
	else
		outColor = vec4(0,1,0,0);
	
	outColor = color;
}
